@@ -17,7 +17,7 @@ this program. If not, see <https://www.gnu.org/licenses/>.
 
 #include "Collision.h"
 #include "CollisionType.h"
-#include "DrawList.h"
+#include "shader/DrawList.h"
 #include "image/Mask.h"
 #include "Minable.h"
 #include "Projectile.h"
