@@ -15,7 +15,7 @@ this program. If not, see <https://www.gnu.org/licenses/>.
 
 #pragma once
 
-#include "ConditionSet.h"
+#include "ConditionAssignments.h"
 #include "DataNode.h"
 #include "Date.h"
 
@@ -72,6 +72,8 @@ public:
 
 	const std::list<DataNode> &Changes() const;
 
+	// Comparison operator, based on the date of the event.
+	bool operator<(const GameEvent &other) const;
 
 private:
 	Date date;
@@ -79,7 +81,7 @@ private:
 	bool isDisabled = false;
 	bool isDefined = false;
 
-	ConditionSet conditionsToApply;
+	ConditionAssignments conditionsToApply;
 	std::list<DataNode> changes;
 	std::vector<const System *> systemsToVisit;
 	std::vector<const Planet *> planetsToVisit;
