@@ -25,10 +25,10 @@ this program. If not, see <https://www.gnu.org/licenses/>.
 #include "MenuPanel.h"
 #include "PlayerInfo.h"
 #include "Point.h"
-#include "PointerShader.h"
+#include "shader/PointerShader.h"
 #include "Ship.h"
 #include "image/SpriteSet.h"
-#include "StarField.h"
+#include "shader/StarField.h"
 #include "System.h"
 #include "TaskQueue.h"
 #include "UI.h"
