@@ -35,10 +35,12 @@ public:
 	const Rectangle &GetCustomRegion() const;
 	bool HasCustomRegion() const;
 
-	void SetSprite(const std::string &name, const Sprite *sprite, const Point &unit = Point(0., -1.), float frame = 0.f);
+	void SetSprite(const std::string &name, const Sprite *sprite, const Point &unit = Point(0., -1.), float frame = 0.f,
+		int swizzle = 0);
 	const Sprite *GetSprite(const std::string &name) const;
 	const Point &GetSpriteUnit(const std::string &name) const;
 	float GetSpriteFrame(const std::string &name) const;
+	int GetSwizzle(const std::string &name) const;
 
 	void SetString(const std::string &name, const std::string &value);
 	const std::string &GetString(const std::string &name) const;
@@ -61,6 +63,7 @@ private:
 	std::map<std::string, const Sprite *> sprites;
 	std::map<std::string, Point> spriteUnits;
 	std::map<std::string, float> spriteFrames;
+	std::map<std::string, int> spriteSwizzles;
 	std::map<std::string, std::string> strings;
 	std::map<std::string, double> bars;
 	std::map<std::string, double> barSegments;
