@@ -22,7 +22,7 @@ this program. If not, see <https://www.gnu.org/licenses/>.
 #include "Dialog.h"
 #include "text/DisplayText.h"
 #include "Files.h"
-#include "FillShader.h"
+#include "shader/FillShader.h"
 #include "text/Font.h"
 #include "text/FontSet.h"
 #include "GameData.h"
@@ -34,7 +34,7 @@ this program. If not, see <https://www.gnu.org/licenses/>.
 #include "PlayerInfo.h"
 #include "Preferences.h"
 #include "Rectangle.h"
-#include "StarField.h"
+#include "shader/StarField.h"
 #include "StartConditionsPanel.h"
 #include "text/truncate.hpp"
 #include "UI.h"
@@ -83,7 +83,7 @@ namespace {
 	}
 
 	// Extract the date from this pilot's most recent save.
-	string FileDate(const string &filename)
+	string FileDate(const filesystem::path &filename)
 	{
 		string date = "0000-00-00";
 		DataFile file(filename);
@@ -294,7 +294,7 @@ bool LoadPanel::KeyDown(SDL_Keycode key, Uint16 mod, const Command &command, boo
 			return false;
 
 		nameToConfirm.clear();
-		string lastSave = Files::Saves() + it->second.front().first;
+		filesystem::path lastSave = Files::Saves() / it->second.front().first;
 		GetUI()->Push(new Dialog(this, &LoadPanel::SnapshotCallback,
 			"Enter a name for this snapshot, or use the most recent save's date:",
 			FileDate(lastSave)));
@@ -396,7 +396,7 @@ bool LoadPanel::KeyDown(SDL_Keycode key, Uint16 mod, const Command &command, boo
 			}
 			selectedFile = it->first;
 		}
-		loadedInfo.Load(Files::Saves() + selectedFile);
+		loadedInfo.Load(Files::Saves() / selectedFile);
 	}
 	else if(key == SDLK_LEFT)
 		sideHasFocus = true;
@@ -450,7 +450,7 @@ bool LoadPanel::Click(int x, int y, int clicks)
 		return false;
 
 	if(!selectedFile.empty())
-		loadedInfo.Load(Files::Saves() + selectedFile);
+		loadedInfo.Load(Files::Saves() / selectedFile);
 
 	return true;
 }
@@ -500,11 +500,11 @@ void LoadPanel::UpdateLists()
 {
 	files.clear();
 
-	vector<string> fileList = Files::List(Files::Saves());
-	for(const string &path : fileList)
+	vector<filesystem::path> fileList = Files::List(Files::Saves());
+	for(const auto &path : fileList)
 	{
 		// Skip any files that aren't text files.
-		if(path.compare(path.length() - 4, 4, ".txt"))
+		if(path.extension() != ".txt")
 			continue;
 
 		string fileName = Files::Name(path);
@@ -546,7 +546,7 @@ void LoadPanel::UpdateLists()
 			if(it != files.end())
 			{
 				selectedFile = it->second.front().first;
-				loadedInfo.Load(Files::Saves() + selectedFile);
+				loadedInfo.Load(Files::Saves() / selectedFile);
 			}
 		}
 	}
@@ -561,13 +561,13 @@ void LoadPanel::SnapshotCallback(const string &name)
 	if(it == files.end() || it->second.empty() || it->second.front().first.size() < 4)
 		return;
 
-	string from = Files::Saves() + it->second.front().first;
+	filesystem::path from = Files::Saves() / it->second.front().first;
 	string suffix = name.empty() ? FileDate(from) : name;
 	string extension = "~" + suffix + ".txt";
 
 	// If a file with this name already exists, make sure the player
 	// actually wants to overwrite it.
-	string to = from.substr(0, from.size() - 4) + extension;
+	filesystem::path to = from.parent_path() / (from.stem().string() + extension);
 	if(Files::Exists(to) && suffix != nameToConfirm)
 	{
 		nameToConfirm = suffix;
@@ -581,18 +581,17 @@ void LoadPanel::SnapshotCallback(const string &name)
 
 
 // This name is the one to be used, even if it already exists.
-void LoadPanel::WriteSnapshot(const string &sourceFile, const string &snapshotName)
+void LoadPanel::WriteSnapshot(const filesystem::path &sourceFile, const filesystem::path &snapshotName)
 {
 	// Copy the autosave to a new, named file.
-	Files::Copy(sourceFile, snapshotName);
-	if(Files::Exists(snapshotName))
+	if(Files::Copy(sourceFile, snapshotName))
 	{
 		UpdateLists();
 		selectedFile = Files::Name(snapshotName);
-		loadedInfo.Load(Files::Saves() + selectedFile);
+		loadedInfo.Load(Files::Saves() / selectedFile);
 	}
 	else
-		GetUI()->Push(new Dialog("Error: unable to create the file \"" + snapshotName + "\"."));
+		GetUI()->Push(new Dialog("Error: unable to create the file \"" + snapshotName.string() + "\"."));
 }
 
 
@@ -632,7 +631,7 @@ void LoadPanel::DeletePilot(const string &)
 	bool failed = false;
 	for(const auto &fit : it->second)
 	{
-		string path = Files::Saves() + fit.first;
+		filesystem::path path = Files::Saves() / fit.first;
 		Files::Delete(path);
 		failed |= Files::Exists(path);
 	}
@@ -651,7 +650,7 @@ void LoadPanel::DeleteSave()
 {
 	loadedInfo.Clear();
 	string pilot = selectedPilot;
-	string path = Files::Saves() + selectedFile;
+	filesystem::path path = Files::Saves() / selectedFile;
 	Files::Delete(path);
 	if(Files::Exists(path))
 		GetUI()->Push(new Dialog("Deleting snapshot file failed."));
@@ -665,7 +664,7 @@ void LoadPanel::DeleteSave()
 	{
 		selectedFile = it->second.front().first;
 		selectedPilot = pilot;
-		loadedInfo.Load(Files::Saves() + selectedFile);
+		loadedInfo.Load(Files::Saves() / selectedFile);
 		sideHasFocus = false;
 	}
 }
