@@ -16,9 +16,10 @@ this program. If not, see <https://www.gnu.org/licenses/>.
 #include "MessageLogPanel.h"
 
 #include "text/alignment.hpp"
+#include "audio/Audio.h"
 #include "Color.h"
 #include "Command.h"
-#include "FillShader.h"
+#include "shader/FillShader.h"
 #include "text/Font.h"
 #include "text/FontSet.h"
 #include "GameData.h"
@@ -28,7 +29,7 @@ this program. If not, see <https://www.gnu.org/licenses/>.
 #include "Screen.h"
 #include "image/Sprite.h"
 #include "image/SpriteSet.h"
-#include "SpriteShader.h"
+#include "shader/SpriteShader.h"
 #include "UI.h"
 #include "text/WrappedText.h"
 
@@ -44,11 +45,19 @@ namespace {
 MessageLogPanel::MessageLogPanel()
 	: messages(Messages::GetLog()), width(GameData::Interfaces().Get("message log")->GetValue("width"))
 {
+	Audio::Pause();
 	SetInterruptible(false);
 }
 
 
 
+MessageLogPanel::~MessageLogPanel()
+{
+	Audio::Resume();
+}
+
+
+
 void MessageLogPanel::Draw()
 {
 	// Dim out everything outside this panel.
