@@ -34,7 +34,7 @@ this program. If not, see <https://www.gnu.org/licenses/>.
 #include "Ship.h"
 #include "image/Sprite.h"
 #include "image/SpriteSet.h"
-#include "SpriteShader.h"
+#include "shader/SpriteShader.h"
 #include "text/truncate.hpp"
 #include "UI.h"
 
@@ -168,6 +168,9 @@ void OutfitterPanel::DrawItem(const string &name, const Point &point)
 
 	const Font &font = FontSet::Get(14);
 	const Color &bright = *GameData::Colors().Get("bright");
+	const Color &highlight = *GameData::Colors().Get("outfitter difference highlight");
+
+	bool highlightDifferences = false;
 	if(playerShip || isLicense || mapSize)
 	{
 		int minCount = numeric_limits<int>::max();
@@ -178,8 +181,16 @@ void OutfitterPanel::DrawItem(const string &name, const Point &point)
 			minCount = maxCount = player.HasMapped(mapSize);
 		else
 		{
+			highlightDifferences = true;
+			string firstModelName;
 			for(const Ship *ship : playerShips)
 			{
+				// Highlight differences in installed outfit counts only when all selected ships are of the same model.
+				string modelName = ship->TrueModelName();
+				if(firstModelName.empty())
+					firstModelName = modelName;
+				else
+					highlightDifferences &= (modelName == firstModelName);
 				int count = ship->OutfitCount(outfit);
 				minCount = min(minCount, count);
 				maxCount = max(maxCount, count);
@@ -189,13 +200,19 @@ void OutfitterPanel::DrawItem(const string &name, const Point &point)
 		if(maxCount)
 		{
 			string label = "installed: " + to_string(minCount);
+			Color color = bright;
 			if(maxCount > minCount)
+			{
 				label += " - " + to_string(maxCount);
+				if(highlightDifferences)
+					color = highlight;
+			}
 
 			Point labelPos = point + Point(-OUTFIT_SIZE / 2 + 20, OUTFIT_SIZE / 2 - 38);
-			font.Draw(label, labelPos, bright);
+			font.Draw(label, labelPos, color);
 		}
 	}
+
 	// Don't show the "in stock" amount if the outfit has an unlimited stock.
 	int stock = 0;
 	if(!outfitter.Has(outfit))
@@ -375,7 +392,8 @@ ShopPanel::BuyResult OutfitterPanel::CanBuy(bool onlyOwned) const
 			"It is being shown in the list because you have one, "
 			"but this " + planet->Noun() + " does not sell them.";
 	}
-
+	// Add system to accumulate reasons why an outfit cannot be bought
+	vector<string> errors;
 	// Check if you need to pay, and can't afford it.
 	if(!onlyOwned)
 	{
@@ -384,87 +402,107 @@ ShopPanel::BuyResult OutfitterPanel::CanBuy(bool onlyOwned) const
 		int64_t credits = player.Accounts().Credits();
 
 		if(cost > credits)
-			return "You cannot buy this outfit, because it costs "
-				+ Format::CreditString(cost) + ", and you only have "
-				+ Format::Credits(credits) + ".";
+			errors.push_back("You do not have enough money to buy this outfit. You need a further " +
+				Format::CreditString(cost - credits));
 
 		// Add the cost to buy the required license.
-		if(cost + licenseCost > credits)
-			return "You don't have enough money to buy this outfit, because it will cost you an extra "
-				+ Format::CreditString(licenseCost) + " to buy the necessary licenses.";
+		else if(cost + licenseCost > credits)
+			errors.push_back("You do not have enough money to buy this outfit because you also need "
+				"to buy a license for it. You need a further " +
+				Format::CreditString(cost + licenseCost - credits));
 	}
 
-	// Check if the outfit will fit
+	bool anyShipCanInstall = true;
+	// Check if the outfit will fit.
 	if(!playerShip)
 	{
 		// Buying into cargo, so check cargo space vs mass.
 		double mass = selectedOutfit->Mass();
 		double freeCargo = player.Cargo().FreePrecise();
-		if(!mass || freeCargo >= mass)
-			return true;
-
-		return "You cannot " + string(onlyOwned ? "load" : "buy") + " this outfit, because it takes up "
-			+ Format::CargoString(mass, "mass") + " and your fleet has "
-			+ Format::CargoString(freeCargo, "cargo space") + " free.";
+		if(mass && freeCargo < mass)
+			errors.push_back("You cannot " + string(onlyOwned ? "load" : "buy") + " this outfit, because it takes up "
+				+ Format::CargoString(mass, "mass") + " and your fleet has "
+				+ Format::CargoString(freeCargo, "cargo space") + " free.");
 	}
 	else
 	{
+		anyShipCanInstall = false;
 		// Find if any ship can install the outfit.
 		for(const Ship *ship : playerShips)
 			if(ShipCanBuy(ship, selectedOutfit))
-				return true;
+			{
+				anyShipCanInstall = true;
+				break;
+			}
+	}
 
+	if(!anyShipCanInstall)
+	{
 		// If no selected ship can install the outfit,
 		// report error based on playerShip.
 		double outfitNeeded = -selectedOutfit->Get("outfit space");
 		double outfitSpace = playerShip->Attributes().Get("outfit space");
 		if(outfitNeeded > outfitSpace)
-			return "You cannot install this outfit, because it takes up "
+			errors.push_back("You cannot install this outfit, because it takes up "
 				+ Format::CargoString(outfitNeeded, "outfit space") + ", and this ship has "
-				+ Format::MassString(outfitSpace) + " free.";
+				+ Format::MassString(outfitSpace) + " free.");
 
 		double weaponNeeded = -selectedOutfit->Get("weapon capacity");
 		double weaponSpace = playerShip->Attributes().Get("weapon capacity");
 		if(weaponNeeded > weaponSpace)
-			return "Only part of your ship's outfit capacity is usable for weapons. "
+			errors.push_back("Only part of your ship's outfit capacity is usable for weapons. "
 				"You cannot install this outfit, because it takes up "
 				+ Format::CargoString(weaponNeeded, "weapon space") + ", and this ship has "
-				+ Format::MassString(weaponSpace) + " free.";
+				+ Format::MassString(weaponSpace) + " free.");
 
 		double engineNeeded = -selectedOutfit->Get("engine capacity");
 		double engineSpace = playerShip->Attributes().Get("engine capacity");
 		if(engineNeeded > engineSpace)
-			return "Only part of your ship's outfit capacity is usable for engines. "
+			errors.push_back("Only part of your ship's outfit capacity is usable for engines. "
 				"You cannot install this outfit, because it takes up "
 				+ Format::CargoString(engineNeeded, "engine space") + ", and this ship has "
-				+ Format::MassString(engineSpace) + " free.";
+				+ Format::MassString(engineSpace) + " free.");
 
 		if(selectedOutfit->Category() == "Ammunition")
-			return !playerShip->OutfitCount(selectedOutfit) ?
+			errors.push_back(!playerShip->OutfitCount(selectedOutfit) ?
 				"This outfit is ammunition for a weapon. "
 				"You cannot install it without first installing the appropriate weapon."
 				: "You already have the maximum amount of ammunition for this weapon. "
-				"If you want to install more ammunition, you must first install another of these weapons.";
+				"If you want to install more ammunition, you must first install another of these weapons.");
 
 		int mountsNeeded = -selectedOutfit->Get("turret mounts");
 		int mountsFree = playerShip->Attributes().Get("turret mounts");
 		if(mountsNeeded && !mountsFree)
-			return "This weapon is designed to be installed on a turret mount, "
-				"but your ship does not have any unused turret mounts available.";
+			errors.push_back("This weapon is designed to be installed on a turret mount, "
+				"but your ship does not have any unused turret mounts available.");
 
 		int gunsNeeded = -selectedOutfit->Get("gun ports");
 		int gunsFree = playerShip->Attributes().Get("gun ports");
 		if(gunsNeeded && !gunsFree)
-			return "This weapon is designed to be installed in a gun port, "
-				"but your ship does not have any unused gun ports available.";
+			errors.push_back("This weapon is designed to be installed in a gun port, "
+				"but your ship does not have any unused gun ports available.");
 
 		if(selectedOutfit->Get("installable") < 0.)
-			return "This item is not an outfit that can be installed in a ship.";
+			errors.push_back("This item is not an outfit that can be installed in a ship.");
 
 		// For unhandled outfit requirements, show a catch-all error message.
-		return "You cannot install this outfit in your ship, "
-			"because it would reduce one of your ship's attributes to a negative amount. "
-			"For example, it may use up more cargo space than you have left.";
+		if(errors.empty())
+			errors.push_back("You cannot install this outfit in your ship, "
+				"because it would reduce one of your ship's attributes to a negative amount. "
+				"For example, it may use up more cargo space than you have left.");
+	}
+
+	if(errors.empty())
+		return true;
+	else if(errors.size() == 1)
+		return errors[0];
+	else
+	{
+		string errorMessage = "There are several reasons why you cannot " +
+			string(onlyOwned ? "install" : "buy") + " this outfit:\n";
+		for(size_t i = 0; i < errors.size(); ++i)
+			errorMessage += "- " + errors[i] + "\n";
+		return errorMessage;
 	}
 }
 
