@@ -46,7 +46,7 @@ Visual::Visual(const Effect &effect, Point pos, Point vel, Angle facing, Point h
 		velocity += angle.Unit() * Random::Real() * effect.randomVelocity;
 
 	if(effect.sound)
-		Audio::Play(effect.sound, position);
+		Audio::Play(effect.sound, position, effect.soundCategory);
 
 	if(effect.randomFrameRate)
 		AddFrameRate(effect.randomFrameRate * Random::Real());
