@@ -67,8 +67,9 @@ public:
 	void Wrap(const std::string &str);
 	void Wrap(const char *str);
 
-	// Get the height of the wrapped text.
-	int Height() const;
+	/// Get the height of the wrapped text.
+	/// With trailingBreak, include a paragraph break after the text.
+	int Height(bool trailingBreak = true) const;
 
 	// Return the width of the longest line of the wrapped text.
 	int LongestLineWidth() const;
